@@ -34,7 +34,7 @@
 #define _GLIBCXX_RELEASE 13
 
 // The datestamp of the C++ library in compressed ISO date format.
-#define __GLIBCXX__ 20240113
+#define __GLIBCXX__ 20240614
 
 // Macros for various attributes.
 //   _GLIBCXX_PURE
@@ -1090,7 +1090,7 @@ namespace __gnu_cxx
 #define _GLIBCXX_HAVE_LDEXPL 1
 
 /* Define to 1 if you have the <libintl.h> header file. */
-/* #undef _GLIBCXX_HAVE_LIBINTL_H */
+#define _GLIBCXX_HAVE_LIBINTL_H 1
 
 /* Only used in build directory testsuite_hooks.h. */
 #define _GLIBCXX_HAVE_LIMIT_AS 1
@@ -1871,7 +1871,7 @@ namespace __gnu_cxx
 #define _GLIBCXX_USE_NANOSLEEP 1
 
 /* Define if NLS translations are to be used. */
-/* #undef _GLIBCXX_USE_NLS */
+#define _GLIBCXX_USE_NLS 1
 
 /* Define if pthreads_num_processors_np is available in <pthread.h>. */
 /* #undef _GLIBCXX_USE_PTHREADS_NUM_PROCESSORS_NP */
